==> jc-1.4.0.tar.gz: javax/security/auth/DestroyFailedException.h <==
// public class javax.security.auth.DestroyFailedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fb6bf33cef741f55 javax_security_auth_DestroyFailedException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_auth_DestroyFailedException_H_
#define _JC_javax_security_auth_DestroyFailedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_DestroyFailedException$sub_refs	_jc_javax_security_auth_DestroyFailedException$sub_refs;
typedef struct _jc_javax_security_auth_DestroyFailedException$sub_nonrefs	_jc_javax_security_auth_DestroyFailedException$sub_nonrefs;
typedef struct _jc_javax_security_auth_DestroyFailedException$refs	_jc_javax_security_auth_DestroyFailedException$refs;
typedef struct _jc_javax_security_auth_DestroyFailedException$nonrefs	_jc_javax_security_auth_DestroyFailedException$nonrefs;
typedef struct _jc_javax_security_auth_DestroyFailedException$object	_jc_javax_security_auth_DestroyFailedException$object;

typedef const struct _jc_javax_security_auth_DestroyFailedException$vmethods	_jc_javax_security_auth_DestroyFailedException$vmethods;
typedef const struct _jc_javax_security_auth_DestroyFailedException$vtable	_jc_javax_security_auth_DestroyFailedException$vtable;
typedef const struct _jc_javax_security_auth_DestroyFailedException$vtype	_jc_javax_security_auth_DestroyFailedException$vtype;

// Constructors
extern void _jc_javax_security_auth_DestroyFailedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_DestroyFailedException$object *);
extern void _jc_javax_security_auth_DestroyFailedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_DestroyFailedException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_auth_DestroyFailedException$vmethods {
};

// Vtable
struct _jc_javax_security_auth_DestroyFailedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_auth_DestroyFailedException$vmethods	javax_security_auth_DestroyFailedException;
};

// Vtype
struct _jc_javax_security_auth_DestroyFailedException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_DestroyFailedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_DestroyFailedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_DestroyFailedException$refs {
    _jc_javax_security_auth_DestroyFailedException$sub_refs	javax_security_auth_DestroyFailedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_DestroyFailedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_DestroyFailedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_auth_DestroyFailedException$sub_nonrefs	javax_security_auth_DestroyFailedException;
};

// Object instance structure
struct _jc_javax_security_auth_DestroyFailedException$object {
	_jc_javax_security_auth_DestroyFailedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_DestroyFailedException$vtype	*vtype;
	_jc_javax_security_auth_DestroyFailedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_DestroyFailedException$vtype _jc_javax_security_auth_DestroyFailedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_DestroyFailedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_DestroyFailedException$class_object;

#endif	/* _JC_javax_security_auth_DestroyFailedException_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/DestroyFailedException.h <==
// public class javax.security.auth.DestroyFailedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fb6bf33cef741f55 javax_security_auth_DestroyFailedException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_auth_DestroyFailedException_H_
#define _JC_javax_security_auth_DestroyFailedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_DestroyFailedException$sub_refs	_jc_javax_security_auth_DestroyFailedException$sub_refs;
typedef struct _jc_javax_security_auth_DestroyFailedException$sub_nonrefs	_jc_javax_security_auth_DestroyFailedException$sub_nonrefs;
typedef struct _jc_javax_security_auth_DestroyFailedException$refs	_jc_javax_security_auth_DestroyFailedException$refs;
typedef struct _jc_javax_security_auth_DestroyFailedException$nonrefs	_jc_javax_security_auth_DestroyFailedException$nonrefs;
typedef struct _jc_javax_security_auth_DestroyFailedException$object	_jc_javax_security_auth_DestroyFailedException$object;

typedef const struct _jc_javax_security_auth_DestroyFailedException$vmethods	_jc_javax_security_auth_DestroyFailedException$vmethods;
typedef const struct _jc_javax_security_auth_DestroyFailedException$vtable	_jc_javax_security_auth_DestroyFailedException$vtable;
typedef const struct _jc_javax_security_auth_DestroyFailedException$vtype	_jc_javax_security_auth_DestroyFailedException$vtype;

// Constructors
extern void _jc_javax_security_auth_DestroyFailedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_DestroyFailedException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_DestroyFailedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_DestroyFailedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_DestroyFailedException$vmethods {
};

// Vtable
struct _jc_javax_security_auth_DestroyFailedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_auth_DestroyFailedException$vmethods	javax_security_auth_DestroyFailedException;
};

// Vtype
struct _jc_javax_security_auth_DestroyFailedException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_DestroyFailedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_DestroyFailedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_DestroyFailedException$refs {
    _jc_javax_security_auth_DestroyFailedException$sub_refs	javax_security_auth_DestroyFailedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_DestroyFailedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_DestroyFailedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_auth_DestroyFailedException$sub_nonrefs	javax_security_auth_DestroyFailedException;
};

// Object instance structure
struct _jc_javax_security_auth_DestroyFailedException$object {
	_jc_javax_security_auth_DestroyFailedException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_DestroyFailedException$vtype	*vtype;
	_jc_javax_security_auth_DestroyFailedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_DestroyFailedException$vtype _jc_javax_security_auth_DestroyFailedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_DestroyFailedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_DestroyFailedException$class_object;

#endif	/* _JC_javax_security_auth_DestroyFailedException_H_ */
